=============================
django-tinyschedule
=============================

.. image:: https://badge.fury.io/py/django-tinyschedule.png
    :target: https://badge.fury.io/py/django-tinyschedule

.. image:: https://travis-ci.org/jgeskens/django-tinyschedule.png?branch=master
    :target: https://travis-ci.org/jgeskens/django-tinyschedule

.. image:: https://coveralls.io/repos/jgeskens/django-tinyschedule/badge.svg?branch=master 
    :target: https://coveralls.io/r/jgeskens/django-tinyschedule?branch=master

A small package for managing schedules in Django

Documentation
-------------

The full documentation is at https://django-tinyschedule.readthedocs.org.

Quickstart
----------

Install django-tinyschedule::

    pip install django-tinyschedule

Then use it in a project::

    import tinyschedule

Features
--------

* Easily define schedules using the Schedule model
* Make your own Schedule-like models by extending ScheduleBase
* Tiny and lightweight, easy to grasp
